***********************
* This program reproduces the tables in "Direct Democracy and Local Public Goods"
* Benjamin A. Olken
* March 2010
***********************

version 10

capture program drop maketable
program define maketable

local maxrows = 500

syntax using/, rhs(string) varcol(string) [replace] [append]

/*inputs:
 1 = dep variable name
 2 = indep variable name
 3 = variable number (this is the nth variable in the table)*/ 

local lhs = e(depvar)
local newb = _b[`rhs']
local newse = _se[`rhs']
qui test `rhs' = 0
local newp = r(p)

if "`replace'" != "replace" & "`append'" != "append" {
 display "Must specify either replace or append"
 exit 
}

/*initialize dataset*/
preserve
clear
if "`replace'" == "replace" {
 qui set obs `maxrows'
 qui g col0 = ""
 qui g col1 = "`varcol'" in 1
 local whichcol = "col1"
}
else {
 capture insheet using `using'.out, names
 if _rc != 0 {
 display "File not found"
 exit
 }
 local whichcol = ""
 local howmanycols = 0
 foreach X of var col* {
 qui count if `X' == "`varcol'"
 if r(N) > 0 {
  local whichcol = "`X'" 
 }
 local howmanycols = `howmanycols' + 1
 }
 
 if "`whichcol'" == "" {
 /*make a new column*/
 qui g col`howmanycols' = "`varcol'" in 1
 local whichcol = "col`howmanycols'"
 }   
 
 
}



/*find which row to use*/
local lastrow = 0
local brow = 0
foreach X of num 1/`maxrows' {
 qui count if col0 == "`lhs'" in `X'
 if r(N) == 1 & `brow' == 0 {
 local brow = `X' 
 }
 qui count if col0 != "" in `X'
 if r(N) == 1 {
 local lastrow = `X' 
 } 
}
if `brow' == 0 {
 local brow = `lastrow' + 2
 
}


local browse = `brow' + 1
qui replace col0 = "`lhs'" in `brow'
qui replace `whichcol' = string(`newb',"%4.3f") in `brow'
qui replace `whichcol' = "(" + string(`newse',"%4.3f") + ")" in `browse'

qui replace `whichcol' = `whichcol' + "*" in `brow' if `newp' <= 0.10
qui replace `whichcol' = `whichcol' + "*" in `brow' if `newp' <= 0.05
qui replace `whichcol' = `whichcol' + "*" in `brow' if `newp' <= 0.01
 

outsheet using `using'.out, replace

restore
end



*****************
* Table 2
*****************
use clean_table2_village_data,clear


set obs 500

g str40 varname = ""
g outinfo = .
g difftreat = .
g pval = .
g numobs = . 
bys desaid: g tempnum = _n
local numvar = 1
g index = _n

************************
* Table 2 -- summary stats
************************

* village level variables
foreach X of var desa_pop ag_wage asphalt dusun_count church_mosque dist_capital  v_ethnic_frag v_rel_frag vh_age educ v_numvhcan v_morethan1 v_sharevhvoted v_vhvictory v_numaparat v_sharedusunsinap bpd_numpeople v_sharedusunsinbpd bpd_nummeetings bpd_districts ppk_numproj {
	
	local numstd = `numvar' + 1
	qui summ `X' if elect == 0
	replace outinfo = r(mean) in `numvar'
	replace outinfo = -1 * r(sd) in `numstd'
	reg `X' elect wave, robust
	replace difftreat = _b[elect] in `numvar'
	replace difftreat = -1 * _se[elect] in `numstd'
	replace numobs = e(N) in `numvar'
	test elect 
	replace pval = r(p) in `numvar'
	
	replace varname = "`X'" in `numvar'
	local numvar = `numvar' + 2
}

outsheet varname outinfo difftreat pval numobs using table2_village.out,replace 

keep varname outinfo difftreat pval numobs  index
keep if outinfo != .
tempfile tempout
save `tempout',replace



**** HH variables
use clean_table2_hh_data,clear

g str40 varname = ""
g outinfo = .
g difftreat = .
g pval = .
g numobs = . 
g index = 1000 + _n 
bys desaid: g tempnum = _n
local numvar = 1

foreach X of var zlhhexpcap educ female age farmer_buruh muslim {
	
	local numstd = `numvar' + 1
	qui summ `X' if elect == 0
	replace outinfo = r(mean) in `numvar'
	replace outinfo = -1 * r(sd) in `numstd'
	reg `X' elect wave, robust cluster(desaid)
	replace difftreat = _b[elect] in `numvar'
	replace difftreat = -1 * _se[elect] in `numstd'
	replace numobs = e(N) in `numvar'
	test elect 
	replace pval = r(p) in `numvar'
	
	replace varname = "`X'" in `numvar'
	local numvar = `numvar' + 2
}

outsheet varname outinfo difftreat pval numobs using table2_hh.out,replace 

keep varname outinfo difftreat pval numobs  index
keep if outinfo != .
append using `tempout'
keep if outinfo != .
sort index

outsheet varname outinfo difftreat pval numobs using table2.out,replace 


********************
* Table 4
*******************
use clean_table4_data,clear


clogit chosen rd_brid wat_san irrigation  rd_bridXe wat_sanXe irrigationXe  rd_bridXwave_fe wat_sanXwave_fe irrigationXwave_fe,  group(desaXwprojnum) robust cluster (desaid)
test rd_bridXe wat_sanXe irrigationXe
local S1 = r(p)
outreg rd_bridXe wat_sanXe irrigationXe using table4, ti("Impact of Elections on Type of Project Chosen ")  ctitle ("Whole Sample") 3aster coefastr replace se adds(Prob > F, `S1') addnote(Notes: Results from conditional fixed-effects logit regression.,  Robust standard errors in parentheses, adjusted for clustering at the village level.,   Project type fixed effects are included., Education//other is the omitted category.,   The absorb variable is village*women's project in column 1, and village in columns 2 and 3.)

*the next regression limits the sample to the general proposal

clogit chosen rd_brid wat_san irrigation  rd_bridXe wat_sanXe irrigationXe   rd_bridXwave_fe wat_sanXwave_fe irrigationXwave_fe if prop_type=="U",  group(desaid) robust cluster (desaid)
test rd_bridXe wat_sanXe irrigationXe
local S1 = r(p)
outreg rd_bridXe wat_sanXe irrigationXe using table4, ctitle ("General Proposal")  3aster coefastr append se adds(Prob > F, `S1') 

*the next regression limites the sample to the women's proposal

clogit chosen rd_brid wat_san irrigation  rd_bridXe wat_sanXe irrigationXe  rd_bridXwave_fe wat_sanXwave_fe irrigationXwave_fe if prop_type=="P",  group(desaid) robust cluster (desaid)
test rd_bridXe wat_sanXe irrigationXe
local S1 = r(p)
outreg rd_bridXe wat_sanXe irrigationXe using table4, ctitle ("Women's Proposal")  3aster coefastr append se adds(Prob > F, `S1') 

******
* limit to options
*********
clogit chosen rd_brid wat_san irrigation  rd_bridXe wat_sanXe irrigationXe  rd_bridXwave_fe wat_sanXwave_fe irrigationXwave_fe if isanoption == 1,  group(desaXwprojnum) robust cluster (desaid)
test rd_bridXe wat_sanXe irrigationXe
local S1 = r(p)
outreg rd_bridXe wat_sanXe irrigationXe using table4, append 3aster coefastr  se adds(Prob > F, `S1') 

*the next regression limits the sample to the general proposal

clogit chosen rd_brid wat_san irrigation  rd_bridXe wat_sanXe irrigationXe   rd_bridXwave_fe wat_sanXwave_fe irrigationXwave_fe if prop_type=="U" & isanoption == 1,  group(desaid) robust cluster (desaid)
test rd_bridXe wat_sanXe irrigationXe
local S1 = r(p)
outreg rd_bridXe wat_sanXe irrigationXe using table4, ctitle ("General Proposal")  3aster coefastr append se adds(Prob > F, `S1') 

*the next regression limites the sample to the women's proposal

clogit chosen rd_brid wat_san irrigation  rd_bridXe wat_sanXe irrigationXe  rd_bridXwave_fe wat_sanXwave_fe irrigationXwave_fe if prop_type=="P" & isanoption == 1,  group(desaid) robust cluster (desaid)
test rd_bridXe wat_sanXe irrigationXe
local S1 = r(p)
outreg rd_bridXe wat_sanXe irrigationXe using table4, ctitle ("Women's Proposal")  3aster coefastr append se adds(Prob > F, `S1') 



**************
* Table 5
**************
/*Column 1: Sample = both proposals, men & women, household respondents; 
NO project type*election dummies included*/

use clean_table5_data, clear
clogit chosen bridge water irrigation sanitation school rank eXr  rankXwave_fe , group(hidXwprojnum) robust cluster (desaid) 
outreg rank eXr using table5, ti("Impact of Elections on Project Rank (Whole Sample)") ctitle ("Whole Sample")  3aster coefastr replace se addnote(Notes: Results from conditional  fixed-effects logit regression., Robust standard errors in parentheses, adjusted  for clustering at the village level., The individual's most preferred project,  receives a rank of 1. , Project type*elect dummies NOT included., Relatively central dusuns low expenditure households and, wealthy dusuns correspond  to low percentiles.,  The F-statistic gives the  joint significance of the, election rank interactions.,  The absorb variable is respondent*women's project.)

/*Column 2: Sample = both proposals, men & women, household respondents and elite; 
NO project type*election dummies included*/

use clean_table5_data_elite, clear
clogit chosen bridge water irrigation sanitation school rank eXr eliteXrank eliteXrankXe  rankXwave_fe,  group(idXwprojnum) robust cluster (desaid) 
outreg rank eXr eliteXrank eliteXrankXe using table5, ctitle ("Whole Sample")  3aster coefastr append se 

/*Column 3: Sample = both proposals, men & women, household respondents; percentile version of 
	covariates; NO project type*election dummies included*/

use clean_table5_data, clear
clogit chosen bridge water irrigation sanitation school   rank eXr  maleXr maleXeXr hexpcapXr hexpcapXeXr time_voffice_ptileXr time_voffice_ptileXeXr  dus_povsc_ptileXr dus_povsc_ptileXeXr   minority_hhXr minority_hhXeXr  rankXwave_fe, group(hidXwprojnum)  robust cluster (desaid) 
test dus_povsc_ptileXeXr time_voffice_ptileXeXr minority_hhXeXr hexpcapXeXr eXr maleXeXr
local S1 = r(p)
outreg rank eXr maleXr maleXeXr  hexpcapXr hexpcapXeXr time_voffice_ptileXr time_voffice_ptileXeXr  dus_povsc_ptileXr dus_povsc_ptileXeXr minority_hhXr minority_hhXeXr  using table5, ctitle ("Whole Sample")  3aster coefastr append se adds(Prob > F, `S1') 

/*Column 4: General proposal, men & women, household respondents; 
NO project type*election dummies included*/

use clean_table5_data, clear
clogit chosen bridge water irrigation sanitation rank eXr  rankXwave_fe if prop_type=="U"  , group(hid) robust cluster (desaid) 
outreg rank eXr using table5, ctitle ("General Proposal")  3aster coefastr append se

/*Column 5: Sample = general proposal, men & women, household respondents and elite; 
NO project type*election dummies included*/

use clean_table5_data_elite, clear
clogit chosen bridge water irrigation sanitation rank eXr eliteXrank eliteXrankXe  rankXwave_fe if prop_type=="U",  group(id_num) robust cluster (desaid) 
outreg rank eXr eliteXrank eliteXrankXe using table5, ctitle ("General Proposal")  3aster coefastr append se 

/*Column 6: Sample = general proposal, men & women, household respondents; percentile version of 
	covariates; NO project type*election dummies included*/

use clean_table5_data, clear
clogit chosen bridge water irrigation sanitation rank eXr  maleXr maleXeXr hexpcapXr hexpcapXeXr time_voffice_ptileXr time_voffice_ptileXeXr  dus_povsc_ptileXr dus_povsc_ptileXeXr   minority_hhXr minority_hhXeXr   rankXwave_fe if prop_type=="U" , group(hid) robust cluster (desaid) 
test dus_povsc_ptileXeXr time_voffice_ptileXeXr minority_hhXeXr hexpcapXeXr eXr maleXeXr
local S1 = r(p)
outreg rank eXr maleXr maleXeXr  hexpcapXr hexpcapXeXr time_voffice_ptileXr time_voffice_ptileXeXr  dus_povsc_ptileXr dus_povsc_ptileXeXr minority_hhXr minority_hhXeXr  using table5, ctitle ("General Proposal")  3aster coefastr append se adds(Prob > F, `S1') 

/*Column 7: Women's proposal, men & women, household respondents; 
NO project type*election dummies included*/

use clean_table5_data, clear
clogit chosen bridge water sanitation school rank eXr  rankXwave_fe if prop_type=="P"  , group(hid) robust cluster (desaid) 
outreg rank eXr using table5, ctitle ("Women's Proposal")  3aster coefastr append se

/*Column 8: Sample = women's proposal, men & women, household respondents and elite; 
NO project type*election dummies included*/

use clean_table5_data_elite, clear
clogit chosen bridge water sanitation school rank eXr eliteXrank eliteXrankXe  rankXwave_fe if prop_type=="P",  group(id_num) robust cluster (desaid) 
outreg rank eXr eliteXrank eliteXrankXe using table5, ctitle ("Women's Proposal")  3aster coefastr append se 

/*Column 9: Sample = women's proposal, men & women, household respondents; percentile version of 
	covariates; NO project type*election dummies included*/

use clean_table5_data, clear
clogit chosen bridge water sanitation school   rank eXr  maleXr maleXeXr hexpcapXr hexpcapXeXr time_voffice_ptileXr time_voffice_ptileXeXr  dus_povsc_ptileXr dus_povsc_ptileXeXr   minority_hhXr minority_hhXeXr   rankXwave_fe if prop_type=="P", group(hid) robust cluster (desaid) 
test dus_povsc_ptileXeXr time_voffice_ptileXeXr minority_hhXeXr hexpcapXeXr eXr maleXeXr
local S1 = r(p)
outreg rank eXr maleXr maleXeXr  hexpcapXr hexpcapXeXr time_voffice_ptileXr time_voffice_ptileXeXr  dus_povsc_ptileXr dus_povsc_ptileXeXr minority_hhXr minority_hhXeXr  using table5, ctitle ("Women's Propposal")  3aster coefastr append se adds(Prob > F, `S1') 


**************
* Table 6
*************
use clean_table6_data,clear

clogit chosen dus_povr_ptile sh_pop time_voffice_ptile min_dus  dus_povr_ptileXe sh_popXe time_voffice_ptileXe min_dusXe  dus_povr_ptileXphase sh_popXphase time_voffice_ptileXphase min_dusXphase,  group(desaXwprojnum) 
test dus_povr_ptileXe sh_popXe time_voffice_ptileXe min_dusXe
local S1 = r(p)

outreg dus_povr_ptile dus_povr_ptileXe sh_pop sh_popXe  time_voffice_ptile time_voffice_ptileXe min_dus min_dusXe using  table6, ti("Impact of Elections on Project Location") ctitle ("Both Proposals")  3aster coefastr replace se adds(Prob > F, `S1') addnote(Notes: Results from conditional  fixed-effects logit regression., Robust standard errors in parentheses, adjusted  for clustering at the village level., A high percentile corresponds to relatively  poor dusuns populous dusuns and distant dusuns., The F-statistic gives the  joint significance of the, dusun characteristic*election interactions.,  The absorb variable is village*women's project in column 1, and village  in columns 2 and 3.)

clogit chosen dus_povr_ptile sh_pop time_voffice_ptile min_dus  dus_povr_ptileXe sh_popXe time_voffice_ptileXe min_dusXe  dus_povr_ptileXphase sh_popXphase time_voffice_ptileXphase  min_dusXphase if prop_type=="U",  group(desaid) 
test dus_povr_ptileXe sh_popXe time_voffice_ptileXe min_dusXe
local S1 = r(p)
outreg dus_povr_ptile dus_povr_ptileXe sh_pop sh_popXe  time_voffice_ptile time_voffice_ptileXe min_dus min_dusXe using  table6, ctitle ("General Proposal")  3aster coefastr append se adds(Prob > F, `S1') 

clogit chosen dus_povr_ptile sh_pop time_voffice_ptile  dus_povr_ptileXe sh_popXe time_voffice_ptileXe  dus_povr_ptileXphase sh_popXphase time_voffice_ptileXphase  if prop_type=="P",  group(desaid) 
test dus_povr_ptileXe sh_popXe time_voffice_ptileXe 
local S1 = r(p)
outreg dus_povr_ptile dus_povr_ptileXe sh_pop sh_popXe  time_voffice_ptile time_voffice_ptileXe using  table6, ctitle ("Women's Proposal")  3aster coefastr append se adds(Prob > F, `S1') 

***************
* Table 7
****************
use clean_table7_10_data,clear

replace benefit = . if benefit > 4
replace use = . if benefit > 4

for var sat_prop benefit fair aspire kdp_satw2 : replace X = (X - 1) / 3

reg sat_prop elect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table7, rhs(elect) varcol(Pooled) replace

reg sat_prop elect phase2 age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if prop_type=="U" & male == 1, robust cluster (desaid)
maketable using table7, rhs(elect) varcol(General-Men) append

reg sat_prop elect phase2 age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if prop_type=="U" & male == 0, robust cluster (desaid)
maketable using table7, rhs(elect) varcol(General-Women) append

reg sat_prop elect phase2 age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if prop_type=="P" & male == 1, robust cluster (desaid)
maketable using table7, rhs(elect) varcol(WomenProj-Men) append

reg sat_prop elect phase2 age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if prop_type=="P" & male == 0, robust cluster (desaid)
maketable using table7, rhs(elect) varcol(WomenProj-Women) append


* Will proposal benefit you personally 
reg benefit elect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table7, rhs(elect) varcol(Pooled) append

reg benefit elect phase2 age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if prop_type=="U" & male == 1, robust cluster (desaid)
maketable using table7, rhs(elect) varcol(General-Men) append

reg benefit elect phase2 age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if prop_type=="U" & male == 0, robust cluster (desaid)
maketable using table7, rhs(elect) varcol(General-Women) append

reg benefit elect phase2 age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if prop_type=="P" & male == 1, robust cluster (desaid)
maketable using table7, rhs(elect) varcol(WomenProj-Men) append


reg benefit elect phase2 age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if prop_type=="P" & male == 0, robust cluster (desaid)
maketable using table7, rhs(elect) varcol(WomenProj-Women) append


* Will you use project?
reg use elect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table7, rhs(elect) varcol(Pooled) append

reg use elect phase2  age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if prop_type=="U" & male == 1, robust cluster (desaid)
maketable using table7, rhs(elect) varcol(General-Men) append

reg use elect phase2  age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if prop_type=="U" & male == 0, robust cluster (desaid)
maketable using table7, rhs(elect) varcol(General-Women) append

reg use elect phase2  age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if prop_type=="P" & male == 1, robust cluster (desaid)
maketable using table7, rhs(elect) varcol(WomenProj-Men) append

reg use elect phase2  age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if prop_type=="P" & male == 0, robust cluster (desaid)
maketable using table7, rhs(elect) varcol(WomenProj-Women) append


* Was chosen proposal fair? 

reg fair elect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table7, rhs(elect) varcol(Pooled) append

reg fair elect phase2  age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if prop_type=="U" & male == 1, robust cluster (desaid)
maketable using table7, rhs(elect) varcol(General-Men) append

reg fair elect phase2  age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if prop_type=="U" & male == 0, robust cluster (desaid)
maketable using table7, rhs(elect) varcol(General-Women) append

reg fair elect phase2  age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if prop_type=="P" & male == 1, robust cluster (desaid)
maketable using table7, rhs(elect) varcol(WomenProj-Men) append

reg fair elect phase2  age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if prop_type=="P" & male == 0, robust cluster (desaid)
maketable using table7, rhs(elect) varcol(WomenProj-Women) append

* Is the chosen proposal in accordance with people's aspirations

reg aspire elect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table7, rhs(elect) varcol(Pooled) append

reg aspire elect phase2  age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if prop_type=="U" & male == 1, robust cluster (desaid)
maketable using table7, rhs(elect) varcol(General-Men) append

reg aspire elect phase2  age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if prop_type=="U" & male == 0, robust cluster (desaid)
maketable using table7, rhs(elect) varcol(General-Women) append

reg aspire elect phase2  age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if prop_type=="P" & male == 1, robust cluster (desaid)
maketable using table7, rhs(elect) varcol(WomenProj-Men) append

reg aspire elect phase2  age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if prop_type=="P" & male == 0, robust cluster (desaid)
maketable using table7, rhs(elect) varcol(WomenProj-Women) append

*Are you satisfied with KDP?

reg kdp_satw2 elect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table7, rhs(elect) varcol(Pooled) append

reg kdp_satw2 elect phase2  age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if male == 1, robust cluster (desaid)
maketable using table7, rhs(elect) varcol(General-Men) append

reg kdp_satw2 elect phase2  age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if male == 0, robust cluster (desaid)
maketable using table7, rhs(elect) varcol(General-Women) append


* Job approval


reg jobapproval_pres elect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table7, rhs(elect) varcol(Pooled) append

reg jobapproval_pres elect phase2  age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if male == 1, robust cluster (desaid)
maketable using table7, rhs(elect) varcol(General-Men) append

reg jobapproval_pres elect phase2  age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if male == 0, robust cluster (desaid)
maketable using table7, rhs(elect) varcol(General-Women) append


reg jobapproval_vh elect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table7, rhs(elect) varcol(Pooled) append

reg jobapproval_vh elect phase2  age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if male == 1, robust cluster (desaid)
maketable using table7, rhs(elect) varcol(General-Men) append

reg jobapproval_vh elect phase2  age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if male == 0, robust cluster (desaid)
maketable using table7, rhs(elect) varcol(General-Women) append


*******************
* Table 8
*********************
use clean_table8_10_data,clear

*Pooled Sample
reg labor elect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table8, rhs(elect) varcol(Pooled) replace

reg money elect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table8, rhs(elect) varcol(Pooled) append

reg contribute elect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table8, rhs(elect) varcol(Pooled) append


*General Proposal - Men 
reg labor elect phase2 age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if prop_type=="U" & male == 1,  robust cluster (desaid)
maketable using table8, rhs(elect) varcol(General_Men) append

reg money elect phase2 age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if prop_type=="U" & male == 1,  robust cluster (desaid)
maketable using table8, rhs(elect) varcol(General_Men) append

reg contribute elect phase2 age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if prop_type=="U" & male == 1,  robust cluster (desaid)
maketable using table8, rhs(elect) varcol(General_Men) append


*General Proposal - Women
reg labor elect phase2 age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if prop_type=="U" & male == 0,  robust cluster (desaid)
maketable using table8, rhs(elect) varcol(General_Women) append

reg money elect phase2 age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if prop_type=="U" & male == 0,  robust cluster (desaid)
maketable using table8, rhs(elect) varcol(General_Women) append

reg contribute elect phase2 age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if prop_type=="U" & male == 0,  robust cluster (desaid)
maketable using table8, rhs(elect) varcol(General_Women) append

*Women Proposal - Men 
reg labor elect phase2 age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if prop_type=="P" & male == 1,  robust cluster (desaid)
maketable using table8, rhs(elect) varcol(Women's_Men) append

reg money elect phase2 age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if prop_type=="P" & male == 1,  robust cluster (desaid)
maketable using table8, rhs(elect) varcol(Women's_Men) append

reg contribute elect phase2 age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if prop_type=="P" & male == 1,  robust cluster (desaid)
maketable using table8, rhs(elect) varcol(Women's_Men) append


*Women Proposal - Women
reg labor elect phase2 age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if prop_type=="P" & male == 0,  robust cluster (desaid)
maketable using table8, rhs(elect) varcol(Women's_Women) append

reg money elect phase2 age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if prop_type=="P" & male == 0,  robust cluster (desaid)
maketable using table8, rhs(elect) varcol(Women's_Women) append

reg contribute elect phase2 age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if prop_type=="P" & male == 0,  robust cluster (desaid)
maketable using table8, rhs(elect) varcol(Women's_Women) append


*************
* Table 9, panel A
*************

use clean_table9_A_data,clear

replace benefit = . if benefit > 4
replace use = . if benefit > 4

for var sat_prop benefit fair aspire kdp_satw2 : replace X = (X - 1) / 3


local first = 0
foreach Y of any sat_prop benefit use fair aspire kdp_satw2 {
	
		reg `Y' elect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
		if `first' == 0 {
				maketable using table9, rhs(elect) varcol(Baseline) replace
				local first = 1
			}
		else {
			maketable using table9, rhs(elect) varcol(Baseline) append
		} 
		
		reg `Y' elect proj_consdum phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
		maketable using table9, rhs(elect) varcol(InDusun) append
		
		reg `Y' elect project_type_dum_? phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
		maketable using table9, rhs(elect) varcol(ProjTypes) append
		
		reg `Y' elect rankhh1 phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
		maketable using table9, rhs(elect) varcol(PreferredType) append
		
		xi: reg `Y' elect rankhh1_proj_consdum phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
		maketable using table9, rhs(elect) varcol(PreferredTypeLocation) append
		
		xi: reg `Y' elect resprankgag1 phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
		maketable using table9, rhs(elect) varcol(PreferredProject) append
		
		xi: reg `Y' elect proj_consdum resprankgag1 project_type_dum_? rankhh1 rankhh1_proj_consdum phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
		maketable using table9, rhs(elect) varcol(All) append
		

}		

***
* Panel B
***

use clean_table9_B_data,clear
foreach Y of any labor money contribute {
	
		reg `Y' elect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
  	maketable using table9, rhs(elect) varcol(Baseline) append
		
		reg `Y' elect proj_consdum phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
		maketable using table9, rhs(elect) varcol(InDusun) append
		
		reg `Y' elect project_type_dum_? phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
		maketable using table9, rhs(elect) varcol(ProjTypes) append
		
		reg `Y' elect rankhh1 phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
		maketable using table9, rhs(elect) varcol(PreferredType) append
		
		xi: reg `Y' elect rankhh1_proj_consdum phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
		maketable using table9, rhs(elect) varcol(PreferredTypeLocation) append
		
		xi: reg `Y' elect resprankgag1 phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
		maketable using table9, rhs(elect) varcol(PreferredProject) append

		xi: reg `Y' elect proj_consdum project_type_dum_? rankhh1 rankhh1_proj_consdum resprankgag1 phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
		maketable using table9, rhs(elect) varcol(All) append
		
		
}		




*****************
* Table 10
*****************

use clean_table7_10_data,clear

replace benefit = . if benefit > 4
replace use = . if benefit > 4

for var sat_prop benefit fair aspire kdp_satw2 : replace X = (X - 1) / 3

g elect_inter = elect * meanlhhexpcap
g maineffect = meanlhhexpcap

reg sat_prop elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Exp) replace
lincom elect + elect_inter*11.261 /*10th percentile*/
lincom elect + elect_inter*11.771 /*90th percentile*/

reg benefit elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Exp) append
lincom elect + elect_inter*11.261 /*10th percentile*/
lincom elect + elect_inter*11.771 /*90th percentile*/

reg use elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Exp) append
lincom elect + elect_inter*11.261 /*10th percentile*/
lincom elect + elect_inter*11.771 /*90th percentile*/

reg fair elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Exp) append
lincom elect + elect_inter*11.261 /*10th percentile*/
lincom elect + elect_inter*11.771 /*90th percentile*/

reg aspire elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Exp) append
lincom elect + elect_inter*11.261 /*10th percentile*/
lincom elect + elect_inter*11.771 /*90th percentile*/


reg kdp_satw2 elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Exp) append
lincom elect + elect_inter*11.261 /*10th percentile*/
lincom elect + elect_inter*11.771 /*90th percentile*/


replace elect_inter = elect * meaneduc
replace maineffect =  meaneduc

reg sat_prop elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Educ) append

reg benefit elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Educ) append

reg use elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Educ) append

reg fair elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Educ) append

reg aspire elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Educ) append

reg kdp_satw2 elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Educ) append


replace elect_inter = elect * v_ethnic_frag
replace maineffect =  v_ethnic_frag

reg sat_prop elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(EthFrag) append

reg benefit elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(EthFrag) append

reg use elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(EthFrag) append

reg fair elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(EthFrag) append

reg aspire elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(EthFrag) append

reg kdp_satw2 elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(EthFrag) append



replace elect_inter = elect * v_pctmuslim
replace maineffect =  v_pctmuslim

reg sat_prop elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Muslim) append

reg benefit elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Muslim) append

reg use elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Muslim) append

reg fair elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Muslim) append

reg aspire elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Muslim) append

reg kdp_satw2 elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Muslim) append


replace elect_inter = elect * v_morethan1candidate
replace maineffect = v_morethan1candidate

reg sat_prop elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(TwoCandidates) append

reg benefit elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(TwoCandidates) append

reg use elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(TwoCandidates) append

reg fair elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(TwoCandidates) append

reg aspire elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(TwoCandidates) append

reg kdp_satw2 elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(TwoCandidates) append

replace elect_inter = elect * v_sharevhvoted
replace maineffect = v_sharevhvoted


reg sat_prop elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(ShareVoted) append

reg benefit elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(ShareVoted) append

reg use elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(ShareVoted) append

reg fair elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(ShareVoted) append

reg aspire elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(ShareVoted) append

reg kdp_satw2 elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(ShareVoted) append



replace elect_inter = elect * meanheard
replace maineffect = meanheard 

reg sat_prop elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Heard) append

reg benefit elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Heard) append

reg use elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Heard) append

reg fair elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Heard) append

reg aspire elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Heard) append

reg kdp_satw2 elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Heard) append


use clean_table8_10_data,clear


g elect_inter = elect * meanlhhexpcap
g maineffect = meanlhhexpcap

reg labor elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Exp) append
lincom elect + elect_inter*11.261 /*10th percentile*/
lincom elect + elect_inter*11.771 /*90th percentile*/

reg money elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Exp) append
lincom elect + elect_inter*11.261 /*10th percentile*/
lincom elect + elect_inter*11.771 /*90th percentile*/

reg contribute elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Exp) append
lincom elect + elect_inter*11.261 /*10th percentile*/
lincom elect + elect_inter*11.771 /*90th percentile*/


replace elect_inter = elect * meaneduc
replace maineffect =  meaneduc

reg labor elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Educ) append

reg money elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Educ) append

reg contribute elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Educ) append

replace elect_inter = elect * v_ethnic_frag
replace maineffect =  v_ethnic_frag

reg labor elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(EthFrag) append

reg money elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(EthFrag) append

reg contribute elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(EthFrag) append


replace elect_inter = elect * v_pctmuslim
replace maineffect =  v_pctmuslim

reg labor elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Muslim) append

reg money elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Muslim) append

reg contribute elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Muslim) append


replace elect_inter = elect * v_morethan1candidate
replace maineffect = v_morethan1candidate

reg labor elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(TwoCandidates) append

reg money elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(TwoCandidates) append

reg contribute elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(TwoCandidates) append

replace elect_inter = elect * v_sharevhvoted
replace maineffect = v_sharevhvoted

reg labor elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(ShareVoted) append

reg money elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(ShareVoted) append

reg contribute elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(ShareVoted) append

replace elect_inter = elect * meanheard
replace maineffect = meanheard 

reg labor elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Heard) append

reg money elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Heard) append

reg contribute elect elect_inter maineffect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table10, rhs(elect_inter) varcol(Heard) append


******************
* Table 11
***************
use clean_table11_data,clear

reg correctU elect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table11, rhs(elect) varcol(Pooled) replace

reg correctU elect phase2 age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if male == 1 , robust cluster (desaid)
maketable using table11, rhs(elect) varcol(Men) append

reg correctU elect phase2 age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if male == 0, robust cluster (desaid)
maketable using table11, rhs(elect) varcol(Women) append


reg correctP elect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table11, rhs(elect) varcol(Pooled) append

reg correctP elect phase2 age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if male == 1 , robust cluster (desaid)
maketable using table11, rhs(elect) varcol(Men) append

reg correctP elect phase2 age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if male == 0, robust cluster (desaid)
maketable using table11, rhs(elect) varcol(Women) append


reg discussw2 elect phase2 male age npers c_servant enterp hwife laborer not_in_lf other	priv_comp	student teacher	trader hexpcap, robust cluster (desaid)
maketable using table11, rhs(elect) varcol(Pooled) append

reg discussw2 elect phase2 age npers c_servant enterp hwife laborer not_in_lf other	priv_comp	student teacher	trader hexpcap if male == 1, robust cluster (desaid)
maketable using table11, rhs(elect) varcol(Men) append

reg discussw2 elect phase2 age npers c_servant enterp hwife laborer not_in_lf other	priv_comp	student teacher	trader hexpcap if male == 0, robust cluster (desaid)
maketable using table11, rhs(elect) varcol(Women) append




reg hhdiscussw2 elect phase2 male age npers c_servant enterp hwife laborer not_in_lf other	priv_comp	student teacher	trader hexpcap, robust cluster (desaid)
maketable using table11, rhs(elect) varcol(Pooled) append

reg hhdiscussw2 elect phase2 age npers c_servant enterp hwife laborer not_in_lf other	priv_comp	student teacher	trader hexpcap if male == 1, robust cluster (desaid)
maketable using table11, rhs(elect) varcol(Men) append

reg hhdiscussw2 elect phase2 age npers c_servant enterp hwife laborer not_in_lf other	priv_comp	student teacher	trader hexpcap if male == 0, robust cluster (desaid)
maketable using table11, rhs(elect) varcol(Women) append



reg gldiscussw2 elect phase2 male age npers c_servant enterp hwife laborer not_in_lf other	priv_comp	student teacher	trader hexpcap, robust cluster (desaid)
maketable using table11, rhs(elect) varcol(Pooled) append

reg gldiscussw2 elect phase2 age npers c_servant enterp hwife laborer not_in_lf other	priv_comp	student teacher	trader hexpcap if male == 1, robust cluster (desaid)
maketable using table11, rhs(elect) varcol(Men) append

reg gldiscussw2 elect phase2 age npers c_servant enterp hwife laborer not_in_lf other	priv_comp	student teacher	trader hexpcap if male == 0, robust cluster (desaid)
maketable using table11, rhs(elect) varcol(Women) append


reg transfer_lobby elect phase2 male age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap, robust cluster (desaid)
maketable using table11, rhs(elect) varcol(Pooled) append

reg transfer_lobby elect phase2  age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if male == 1, robust cluster (desaid)
maketable using table11, rhs(elect) varcol(Men) append

reg transfer_lobby elect phase2  age npers c_servant enterp hwife laborer not_in_lf other priv_comp student teacher trader hexpcap if male == 0, robust cluster (desaid)
maketable using table11, rhs(elect) varcol(Women) append




**********
* Figures
************
use clean_figure1_data,clear

set scheme s1mono

graph bar (count) project if prop_type=="U", over(proj_type) over(elect, descending) asyvars percentage stack  bar(1, fi(0))  title(General Project) ytitle(% of Projects)  saving(proj_typeU2, replace) blabel(bar, format(%2.0f) position(center))

graph bar (count) project if prop_type=="P", over(proj_type) over(elect, descending) asyvars percentage stack  bar(1, fi(0)) title(Women's Project) ytitle(% of Projects)   saving(proj_typeP2, replace) blabel(bar, format(%2.0f) position(center))

graph combine proj_typeU2.gph proj_typeP2.gph, xcommon xsize(7) ysize(4)  title (Project Type) saving(proj_type2,replace)
graph export figure1.eps, replace


use clean_figure2_4_data,clear

drop if qdus_pop == .
fillin desaid prop_type dus_povr
replace duproj_cons = 0 if duproj_cons == .
collapse (sum) duproj_cons (mean) elect, by(desaid dus_povr prop_type)
label values elect meetelec
graph bar (mean) duproj_cons if prop_type=="U", over(elect, descending) over(dus_povr)  title(General Project) ytitle(% Construction in Hamlet)   saving(proj_locationU3, replace)

graph bar (mean) duproj_cons if prop_type=="P", over(elect, descending) over(dus_povr)  title(Women's Project) ytitle(% Construction in Hamlet)   saving(proj_locationP3, replace)

graph combine proj_locationU3.gph proj_locationP3.gph, ycommon xsize(10) ysize(4)  title (Project Location) saving(proj_location3,replace)
graph export figure2.eps, replace



use clean_figure2_4_data,clear

drop if qdus_pop == .
fillin desaid prop_type qdus_pop
replace duproj_cons = 0 if duproj_cons == .
collapse (sum) duproj_cons (mean) elect, by(desaid qdus_pop prop_type)
label values elect meetelec

graph bar (mean) duproj_cons if prop_type=="U", over(elect, descending) over(qdus_pop)  title(General Project) ytitle(% Construction in Hamlet)   saving(proj_locationU2, replace)

graph bar (mean) duproj_cons if prop_type=="P", over(elect, descending) over(qdus_pop)  title(Women's Project) ytitle(% Construction in Hamlet)   saving(proj_locationP2, replace)

graph combine proj_locationU2.gph proj_locationP2.gph, ycommon xsize(7) ysize(4)  title (Project Location) saving(proj_location2,replace)
graph export figure3.eps, replace


use clean_figure2_4_data,clear
drop if qtime_voffice == .
fillin desaid prop_type qtime_voffice
replace duproj_cons = 0 if duproj_cons == .
collapse (sum) duproj_cons (mean) elect, by(desaid qtime_voffice prop_type)
label values elect meetelec

graph bar (mean) duproj_cons if prop_type=="U", over(elect, descending) over(qtime_voffice)  title(General Project) ytitle(% Construction in Hamlet)   saving(proj_locationU1, replace)

graph bar (mean) duproj_cons if prop_type=="P", over(elect, descending) over(qtime_voffice)  title(Women's Project) ytitle(% Construction in Hamlet)   saving(proj_locationP1, replace)

graph combine proj_locationU1.gph proj_locationP1.gph, ycommon xsize(7) ysize(4)  title (Project Location) saving(proj_location1,replace)
graph export figure4.eps, replace